@@ -3,7 +3,9 @@
 
 from pymax.cube import Cube
 
-from homevee.Manager.gateway import get_gateway
+from homevee.Helper import Logger
+from homevee.items.Gateway import Gateway
+from homevee.items.Status import *
 
 
 def get_devices(ip):
@@ -12,7 +14,7 @@ def get_devices(ip):
         with Cube(ip) as cube:
             for room in cube.rooms:
                 for device in room.devices:
-                    print device
+                    Logger.log(device)
                     thermostat = {'title': device.name, 'id': device.serial, 'room': room.name}
 
                     thermostats.append(thermostat)
@@ -23,16 +25,16 @@ def get_devices(ip):
 
 
 def set_temp(id, value, db):
-    gateway_data = get_gateway("MAX! Cube", db)
+    gateway = Gateway.load_from_db("MAX! Cube", db)
 
     try:
-        with Cube(gateway_data['IP']) as cube:
+        with Cube(gateway.ip) as cube:
             for room in cube.rooms:
                 for device in room.devices:
                     if id == device.serial:
                         result = cube.set_mode_manual(room.room_id, room.rf_address, float(value))
 
-                        print(result)
+                        Logger.log(result)
 
                         with db:
                             cur = db.cursor()
@@ -40,6 +42,6 @@ def set_temp(id, value, db):
                             cur.execute("UPDATE MAX_THERMOSTATS SET LAST_TEMP = :temp WHERE ID == :id",
                                         {'temp': value, 'id': id})
 
-                        return {'result': 'ok'}
+                        return Status(type=STATUS_OK).get_dict()
     except:
-        return {'result': 'error'}
\ No newline at end of file
+        return Status(type=STATUS_ERROR).get_dict()
\ No newline at end of file
