@@ -1,11 +1,11 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 import json
-import urllib2
+import urllib.request, urllib.error, urllib.parse
 
 
 def get_api_key(cube_ip):
-    contents = urllib2.urlopen("http://"+cube_ip+"/api/link").read()
+    contents = urllib.request.urlopen("http://"+cube_ip+"/api/link").read()
 
     data = json.loads(contents)
 
