@@ -1,23 +1,21 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 import json
-import urllib
+import urllib.error
+import urllib.parse
+import urllib.request
 
-from homevee.Manager.gateway import get_gateway
-from homevee.gateway_keys import RADEMACHER_HOMEPILOT
+from homevee.items.Gateway import *
 
-import heating_control
-import blinds_control
 
 def get_devices(db):
-    data = get_gateway(RADEMACHER_HOMEPILOT, db)
-    ip = data['IP']
+    gateway = Gateway.load_from_db(RADEMACHER_HOMEPILOT, db)
 
     devices = []
 
-    url = "http://"+ip+"/deviceajax.do?devices=1"
+    url = "http://"+gateway.ip+"/deviceajax.do?devices=1"
 
-    response = urllib.urlopen(url).read()
+    response = urllib.request.urlopen(url).read()
 
     data = json.loads(response)
 
