@@ -1,12 +1,7 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-import json
-import os
-
-import requests
 
 from homevee.DeviceAPI.zwave.utils import do_zwave_request
-from homevee.Manager.gateway import get_gateway
 
 
 def get_data(device_id, db):
