@@ -1,13 +1,15 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 import json
-import urllib2
+import urllib.request, urllib.error, urllib.parse
+
+from homevee.Helper import Logger
 
 
 def get_recipe(id):
     url = "https://api.chefkoch.de/v2/recipes/"+str(id)
 
-    result = urllib2.urlopen(url).read()
+    result = urllib.request.urlopen(url).read()
 
     data = json.loads(result)
 
@@ -30,9 +32,9 @@ def search_recipes(keyword, limit=None, offset=None, min_rating=None, max_time=N
     if max_time is not None:
         url = url + "&maximumTime=" + str(max_time)
 
-    print(url)
+    Logger.log(url)
 
-    result = urllib2.urlopen(url).read()
+    result = urllib.request.urlopen(url).read()
 
     result = json.loads(result)
 
