@@ -71,33 +71,41 @@ By default, this script will log summaries to /tmp/retrain_logs directory
 Visualize the summaries with this command:
 tensorboard --logdir /tmp/retrain_logs
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 
-import traceback
-from datetime import datetime
+
+
+
 import hashlib
-import os.path
 import os
+import os.path
 import random
 import re
 import sys
 import tarfile
+import traceback
+from datetime import datetime
 
 import numpy as np
 from six.moves import urllib
-import tensorflow as tf
 
-from tensorflow.python.framework import graph_util
-from tensorflow.python.framework import tensor_shape
-from tensorflow.python.platform import gfile
-from tensorflow.python.util import compat
+from homevee.Helper import Logger
 
-from homevee import constants
-from homevee.db_utils import get_database_con, get_server_data
-from file_utils import get_image_directory_path
-from homevee.firebase_utils import send_notification_to_users
+try:
+    import tensorflow as tf
+    from tensorflow.python.framework import graph_util
+    from tensorflow.python.framework import tensor_shape
+    from tensorflow.python.platform import gfile
+    from tensorflow.python.util import compat
+    TENSORFLOW_INSTALLED = True
+    #Logger.log("Tensorflow imported")
+except:
+    TENSORFLOW_INSTALLED = False
+    Logger.log("Error importing Tensorflow")
+
+from homevee.utils import constants
+from homevee.utils.database import get_database_con, get_server_data
+from homevee.utils.file_utils import get_image_directory_path
+from homevee.utils.firebase_utils import send_notification_to_users
 
 BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 image_dir = get_image_directory_path("ar_control")
@@ -142,10 +150,10 @@ def create_image_lists(image_dir, testing_percentage, validation_percentage):
         cur.execute("SELECT DISTINCT(CONTROL_KEY) FROM (SELECT * FROM AR_CONTROL_LEARNING_DATA WHERE CONTROL_KEY IS NOT NULL)")
 
         for data in cur.fetchall():
-            print(data)
+            Logger.log(data)
             labels.append(data['CONTROL_KEY'])
 
-        print("Labels: " + str(labels))
+        Logger.log("Labels: " + str(labels))
 
         for label in labels:
             cur = db.cursor()
@@ -155,7 +163,7 @@ def create_image_lists(image_dir, testing_percentage, validation_percentage):
 
             for data in cur.fetchall():
                 file_list.extend(gfile.Glob(os.path.join(constants.DATA_DIR, data['PATH'])))
-                print("Pfad: " + str(os.path.join(constants.DATA_DIR, data['PATH'])))
+                Logger.log("Pfad: " + str(os.path.join(constants.DATA_DIR, data['PATH'])))
 
             if len(file_list) < 3:
                 continue
@@ -215,10 +223,10 @@ def create_image_lists(image_dir, testing_percentage, validation_percentage):
 
             label = str(label)
 
-            print(label)
-            print("Validation: " + str(len(validation_images)))
-            print("Testing: " + str(len(testing_images)))
-            print("Training: " + str(len(training_images)))
+            Logger.log(label)
+            Logger.log("Validation: " + str(len(validation_images)))
+            Logger.log("Testing: " + str(len(testing_images)))
+            Logger.log("Training: " + str(len(training_images)))
 
             result[label] = {
                 'dir': os.path.join(constants.DATA_DIR, "images", "ar_control"),
@@ -342,7 +350,6 @@ def maybe_download_and_extract(data_url):
             sys.stdout.flush()
 
         filepath, _ = urllib.request.urlretrieve(data_url, filepath, _progress)
-        print()
         statinfo = os.stat(filepath)
         tf.logging.info('Successfully downloaded', filename, statinfo.st_size,
                         'bytes.')
@@ -466,7 +473,7 @@ def cache_bottlenecks(sess, image_lists, image_dir, bottleneck_dir,
     """
     how_many_bottlenecks = 0
     ensure_dir_exists(bottleneck_dir)
-    for label_name, label_lists in image_lists.items():
+    for label_name, label_lists in list(image_lists.items()):
         for category in ['training', 'testing', 'validation']:
             category_list = label_lists[category]
             for index, unused_base_name in enumerate(category_list):
@@ -507,7 +514,7 @@ def get_random_cached_bottlenecks(sess, image_lists, how_many, category, bottlen
         List of bottleneck arrays, their corresponding ground truths, and the
         relevant filenames.
     """
-    class_count = len(image_lists.keys())
+    class_count = len(list(image_lists.keys()))
     bottlenecks = []
     ground_truths = []
     filenames = []
@@ -569,7 +576,7 @@ def get_random_distorted_bottlenecks(
     Returns:
         List of bottleneck arrays and their corresponding ground truths.
     """
-    class_count = len(image_lists.keys())
+    class_count = len(list(image_lists.keys()))
     bottlenecks = []
     ground_truths = []
     for unused_i in range(how_many):
@@ -931,7 +938,7 @@ def ar_training(username):
     try:
         how_many_training_steps = int(training_steps)
     except:
-        print("error reading AR_TF_TRAINING_STEPS, using default: "+str(how_many_training_steps))
+        Logger.log("error reading AR_TF_TRAINING_STEPS, using default: "+str(how_many_training_steps))
 
     model_size = get_server_data('AR_TF_MODEL_SIZE', db)
     image_size = get_server_data('AR_TF_MODEL_IMAGE_SIZE', db)
@@ -941,7 +948,7 @@ def ar_training(username):
 
         architecture = "mobilenet_" + model_size_string + "_" + image_size_string
     except:
-        print("error reading data, using default architecture: " + str(architecture))
+        Logger.log("error reading data, using default architecture: " + str(architecture))
 
     #os.system("sudo python /var/www/html/python/add-event.py AR-Steuerung Trainieren der Bilder gestartet.")
 
@@ -959,18 +966,19 @@ def ar_training(username):
         return -1
 
     # Set up the pre-trained graph.
-    print(model_info['data_url'])
+    Logger.log(model_info['data_url'])
     try:
         maybe_download_and_extract(model_info['data_url'])
     except Exception as e:
-            traceback.print_exc()
+            if(Logger.IS_DEBUG):
+                traceback.print_exc()
     graph, bottleneck_tensor, resized_image_tensor = (
         create_model_graph(model_info))
 
     # Look at the folder structure, and create lists of all the images.
     image_lists = create_image_lists(image_dir, testing_percentage,
                                      validation_percentage)
-    class_count = len(image_lists.keys())
+    class_count = len(list(image_lists.keys()))
     if class_count == 0:
         tf.logging.error('No valid folders of images found at ' + image_dir)
         #os.system("sudo python /var/www/html/python/add-event.py AR-Steuerung Trainieren der Bilder abgeschlossen.")
@@ -1013,7 +1021,7 @@ def ar_training(username):
         # Add the new layer that we'll be training.
         (train_step, cross_entropy, bottleneck_input, ground_truth_input,
          final_tensor) = add_final_training_ops(
-            len(image_lists.keys()), final_tensor_name, bottleneck_tensor,
+            len(list(image_lists.keys())), final_tensor_name, bottleneck_tensor,
             model_info['bottleneck_tensor_size'])
 
         # Create the operations we need to evaluate the accuracy of our new layer.
@@ -1123,7 +1131,7 @@ def ar_training(username):
         # constants.
         save_graph_to_file(sess, graph, output_graph)
         with gfile.FastGFile(output_labels, 'w') as f:
-            f.write('\n'.join(image_lists.keys()) + '\n')
+            f.write('\n'.join(list(image_lists.keys())) + '\n')
     #os.system("sudo python /var/www/html/python/add-event.py AR-Steuerung Trainieren der Bilder abgeschlossen.")
 
     send_notification_to_users(username, "AR-Steuerung", "Das Training der AR-Steuerung ist abgeschlossen.", db)
