@@ -15,6 +15,6 @@ def compress_string(data):
     return deflate_data
 
 def decompress_string(data):
-    print data
+    print(data)
 
     return zlib.decompress(data)
\ No newline at end of file
