@@ -1,4 +1,5 @@
 from homevee.Helper.helper_functions import has_permission
+from homevee.items.Status import *
 
 def get_permissions(username, db):
     cur = db.cursor()
@@ -14,10 +15,10 @@ def contains_permission(permissions, permission):
 
 def set_permissions(username, permission_user, permissions, db):
     if not has_permission(username, "admin", db):
-        return {'status': 'noadmin'}
+        return Status(type=STATUS_NO_ADMIN).get_dict()
 
     cur = db.cursor()
     cur.execute("UPDATE 'userdata' SET PERMISSIONS = :permissions WHERE USERNAME == :username",
                 {'username':permission_user, 'permissions':permissions})
 
-    return {'status': 'ok'}
\ No newline at end of file
+    return Status(type=STATUS_OK).get_dict()
\ No newline at end of file
