@@ -6,11 +6,13 @@ import json
 from homevee.DeviceAPI.heating import get_thermostats
 from homevee.Functions.calendar import get_calendar_day_items
 from homevee.Functions.nutrition_data import get_user_nutrition_overview
-from homevee.Functions.room_data import get_rooms, get_room_name
+from homevee.Functions.room_data import get_rooms
 from homevee.Functions.sensor_data import get_sensor_data
 from homevee.Functions.weather import get_weather
+from homevee.Helper import Logger
 from homevee.Helper.helper_functions import has_permission
-from homevee.device_types import *
+from homevee.items.Room import Room
+from homevee.utils.device_types import *
 
 STATIC_DASHBOARD_ITEMS = ['calendar', 'weather', 'tvprogramme', 'drivingtime', 'nutritionmanager']
 
@@ -37,13 +39,13 @@ def get_user_dashboard(username, db):
 
             dashboard_keys = []
             for item in dashboard_data['static']:
-                print item
+                Logger.log(item)
                 dashboard_keys.append(item['id'])
 
 
             for item in STATIC_DASHBOARD_ITEMS:
                 if item not in dashboard_keys:
-                    print item+" not existing"
+                    Logger.log(item+" not existing")
                     dashboard_data['static'].append({'id': item, 'checked': False})
 
             dashboard_data['dynamic'] = []
@@ -91,110 +93,102 @@ def get_user_dashboard(username, db):
 
     return {'result': 'unknownuser'}
 
-def get_user_dashboard_items(username, db):
+def get_user_dashboard_items(user, db):
     dashboard_array = []
 
-    with db:
-        cur = db.cursor()
+    data = user.dashboard_data
 
-        cur.execute("SELECT * FROM USERDATA WHERE USERNAME == :username", {'username': username})
+    if data is None:
+        return {'dashboard': dashboard_array}
 
-        db_data = cur.fetchone()
+    data = json.loads(data)
 
-        if db_data is not None:
-            data = db_data['DASHBOARD_DATA']
+    static_items = data['static']
+
+    static_data = {}
+
+    for item in static_items:
+        static_data[item['id']] = item['checked']
+
+    dynamic_temp_items = data['dynamic']
+    devices_map = {}
+    dynamic_items = []
+
+    Logger.log(dynamic_temp_items)
+
+    for item in dynamic_temp_items:
+        found = False
+
+        if (item['type'] not in devices_map):
+            devices_map[item['type']] = []
+
+        if item['id'] not in devices_map[item['type']]:
+            devices_map[item['type']].append(item['id'])
+        else:
+            found = True
+
+        if not found:
+            dynamic_items.append(item)
+
+    Logger.log(dynamic_items)
+
+    # Wetter hinzufügen
+    if 'weather' in static_data:
+        if static_data['weather']:
+            weather_data = get_weather(1, db)
+            dashboard_array.append({'id': 'weather', 'data': weather_data[0]})
+
+    # TV Programm hinzufügen
+    if 'tvprogramme' in static_data:
+        if static_data['tvprogramme']:
+            dashboard_array.append({'id': 'tvprogramme', 'data': None})
+
+    # Kalender hinzufügen
+    if 'calendar' in static_data:
+        if static_data['calendar']:
+            calendar_entries = get_calendar_day_items(user, datetime.datetime.now().strftime("%Y-%m-%d"), db)
+
+            items = calendar_entries['calendar_entries']
+
+            data = None
+            for item in items:
+                start = datetime.datetime.strptime(item['start'], '%H:%M')
+                dnow = datetime.datetime.now()
+
+                if (dnow.time() > start.time()):
+                    continue
+
+                if data is None:
+                    data = item['name'] + " um " + item['start']
+                else:
+                    data += '\n' + item['name'] + " um " + item['start'] + " Uhr"
 
             if data is None:
-                return {'dashboard': dashboard_array}
+                data = 'Keine Termine heute'
 
-            data = json.loads(data)
+            dashboard_array.append({'id': 'calendar', 'data': data})
 
-            static_items = data['static']
+    # Fahrzeit
+    if 'drivingtime' in static_data:
+        if static_data['drivingtime']:
+            dashboard_array.append({'id': 'drivingtime', 'data': '27 min'})
 
-            static_data = {}
+    # Ernährungsmanager
+    if 'nutritionmanager' in static_data:
+        if static_data['nutritionmanager']:
+            calories_left = get_user_nutrition_overview(user, db)['data']['nutrition_day_data']['calories_left']
 
-            for item in static_items:
-                static_data[item['id']] = item['checked']
+            if (calories_left >= 0):
+                text = str(calories_left) + ' Kalorien übrig'
+            else:
+                text = str(calories_left) + ' Kalorien über deinem Ziel'
 
-            dynamic_temp_items = data['dynamic']
-            devices_map = {}
-            dynamic_items = []
+            dashboard_array.append({'id': 'nutritionmanager', 'data': text})
 
-            print dynamic_temp_items
+    if len(dynamic_items) > 0:
+        dashboard_array.append({'id': 'favouritedevices', 'data': None})
 
-            for item in dynamic_temp_items:
-                found = False
-
-                if(item['type'] not in devices_map):
-                    devices_map[item['type']] = []
-
-                if item['id'] not in devices_map[item['type']]:
-                    devices_map[item['type']].append(item['id'])
-                else:
-                    found = True
-
-                if not found:
-                    dynamic_items.append(item)
-
-            print dynamic_items
-
-            # Wetter hinzufügen
-            if 'weather' in static_data:
-                if static_data['weather']:
-                    weather_data = get_weather(1, db)
-                    dashboard_array.append({'id': 'weather', 'data': weather_data[0]})
-
-            # TV Programm hinzufügen
-            if 'tvprogramme' in static_data:
-                if static_data['tvprogramme']:
-                    dashboard_array.append({'id': 'tvprogramme', 'data': None})
-
-            #Kalender hinzufügen
-            if 'calendar' in static_data:
-                if static_data['calendar']:
-                    calendar_entries = get_calendar_day_items(username, datetime.datetime.now().strftime("%Y-%m-%d"), db)
-
-                    items = calendar_entries['calendar_entries']
-
-                    data = None
-                    for item in items:
-                        start = datetime.datetime.strptime(item['start'], '%H:%M')
-                        dnow = datetime.datetime.now()
-
-                        if(dnow.time() > start.time()):
-                            continue
-
-                        if data is None:
-                            data = item['name'] + " um " + item['start']
-                        else:
-                            data += '\n' + item['name'] + " um " + item['start']+ " Uhr"
-
-                    if data is None:
-                        data = 'Keine Termine heute'
-
-                    dashboard_array.append({'id': 'calendar', 'data': data})
-
-            # Fahrzeit
-            if 'drivingtime' in static_data:
-                if static_data['drivingtime']:
-                    dashboard_array.append({'id': 'drivingtime', 'data': '27 min'})
-
-            # Ernährungsmanager
-            if 'nutritionmanager' in static_data:
-                if static_data['nutritionmanager']:
-                    calories_left = get_user_nutrition_overview(username, db)['data']['nutrition_day_data']['calories_left']
-
-                    if(calories_left >= 0):
-                        text = str(calories_left)+' Kalorien übrig'
-                    else:
-                        text = str(calories_left)+' Kalorien über deinem Ziel'
-
-                    dashboard_array.append({'id': 'nutritionmanager', 'data': text})
-
-            if len(dynamic_items) > 0:
-                dashboard_array.append({'id': 'favouritedevices', 'data': None})
-
-        return {'dashboard': dashboard_array}
+    return {'dashboard': dashboard_array}
 
 def edit_user_dashboard(username, dashboard_data, db):
     with db:
@@ -208,7 +202,7 @@ def edit_user_dashboard(username, dashboard_data, db):
         devices_map = {}
         dynamic_items = []
 
-        print dynamic_temp_items
+        Logger.log(dynamic_temp_items)
 
         for item in dynamic_temp_items:
             found = False
@@ -224,7 +218,7 @@ def edit_user_dashboard(username, dashboard_data, db):
             if not found:
                 dynamic_items.append(item)
 
-        print dynamic_items
+        Logger.log(dynamic_items)
 
         dashboard_data['dynamic'] = dynamic_items
 
@@ -249,7 +243,7 @@ def get_user_favourite_devices(username, db):
 
         dynamic_items = data['dynamic']
 
-        print "data: "+str(data)
+        Logger.log("data: "+str(data))
 
         fav_array = get_dynamic_items(username, dynamic_items, db)
 
@@ -274,7 +268,7 @@ def get_dynamic_items(username, dynamic_items, db):
             types[item['type']] = []
 
         types[item['type']].append(item['id'])
-        print types
+        Logger.log(types)
 
     for type in types:
         ids = types[type]
@@ -285,12 +279,12 @@ def get_dynamic_items(username, dynamic_items, db):
                 if item is None:
                     continue
 
-                print favourites
+                Logger.log(favourites)
 
                 favourites[int(item['room'])].append(item)
 
     output = []
-    for location in favourites.keys():
+    for location in list(favourites.keys()):
         room_item = room_map[location]
 
         if len(favourites[location]) > 0:
@@ -301,7 +295,7 @@ def get_dynamic_items(username, dynamic_items, db):
 
 def get_device_info(username, type, id, db):
 
-    print type + " - " + id
+    Logger.log(type + " - " + id)
 
     with db:
         cur = db.cursor()
@@ -393,12 +387,12 @@ def get_device_info(username, type, id, db):
                                'icon': item['ICON'], 'room': item['ROOM'], 'type': 'value',
                                'value': get_sensor_data(username, item['ROOM'], type, id, 1, db)}
         except:
-            print "Error loading device"
+            Logger.log("Error loading device")
 
         if device_data is None or not has_permission(username, device_data['room'], db):
             return None
 
-        device_data['roomname'] = get_room_name(device_data['room'], db)
+        device_data['roomname'] = Room.get_name_by_id(device_data['room'], db)
         device_data['devicetype'] = type
 
         return device_data
