@@ -1,34 +1,34 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 import json
-
 import os
 
+from homevee.DeviceAPI import max_cube, zwave, philips_hue, rademacher_homepilot
 from homevee.Functions.room_data import get_rooms
 from homevee.Functions.sensor_data import SENSOR_TYPE_MAP
-from homevee.device_types import *
-from homevee.DeviceAPI import max_cube, zwave, philips_hue, rademacher_homepilot
+from homevee.Helper import Logger
 from homevee.Helper.helper_functions import has_permission
-from homevee.Manager.gateway import get_gateway
-from homevee.gateway_keys import *
+from homevee.items.Gateway import *
+from homevee.items.Status import *
+from homevee.utils.device_types import *
 
 
 def get_gateway_devices(username, type, db):
     if not has_permission(username, "admin", db):
-        return {'status': 'noadmin'}
+        return Status(type=STATUS_NO_ADMIN).get_dict()
 
-    if type == Z_WAVE:
+    if type == Z_WAVE_GATEWAY:
         return zwave.get_devices.get_devices(db)
-    if type == PHILIPS_HUE_LIGHT:
+    if type == PHILIPS_HUE_BRIDGE:
         return philips_hue.get_devices(db)
     if type == RADEMACHER_HOMEPILOT:
         return rademacher_homepilot.get_devices(db)
     elif type == MAX_CUBE:
-        ip = get_gateway("MAX! Cube", db)['IP']
+        gateway = Gateway.load_from_db("MAX! Cube", db)
 
-        print ip
+        Logger.log(gateway.ip)
 
-        devices = max_cube.get_devices(ip)
+        devices = max_cube.get_devices(gateway.ip)
 
         if devices is not None:
             return {'devices': devices}
@@ -41,7 +41,7 @@ def get_gateway_devices(username, type, db):
 
         ip_adresses = os.popen("arp -a").read()
 
-        print hostnames
+        Logger.log(hostnames)
         #print ip_adresses
 
         #for i in range(0, len(hostnames)):
@@ -85,7 +85,7 @@ function getGatewayDevices($type, $db){
 
 def add_edit_device(username, device_id, type, data, db):
     if not has_permission(username, "admin", db):
-        return {'status': 'noadmin'}
+        return Status(type=STATUS_NO_ADMIN).get_dict()
 
     add_new = (device_id == None or device_id == "" or device_id == "-1")
 
@@ -337,10 +337,10 @@ def add_edit_device(username, device_id, type, data, db):
         else:
             return {'result': 'nosuchtype'}
 
-    return {'result': 'ok'}
+    return Status(type=STATUS_OK).get_dict()
 
 def delete_device(username, type, id, db):
-    type = type.encode('utf-8')
+    #type = type.encode('utf-8')
 
     with db:
         cur = db.cursor()
@@ -372,7 +372,7 @@ def delete_device(username, type, id, db):
 
         data = cur.fetchone()
 
-        print(data)
+        Logger.log(data)
 
         if not has_permission(username, data[db_cols[type]['location']], db):
             return {'result': 'nopermission'}
@@ -380,7 +380,7 @@ def delete_device(username, type, id, db):
         cur.execute("DELETE FROM "+db_cols[type]['table']+" WHERE " + db_cols[type]['id'] + " = :id",
                     {'id': id})
 
-        return {'result': 'ok'}
+        return Status(type=STATUS_OK).get_dict()
 
 '''
 function addEditDevice($deviceId, $type, $data, $db){
@@ -778,7 +778,7 @@ def get_device_data(username, type, id, db):
     for room in get_rooms(username, db)['rooms']:
         room_array[room['location']] = room['name']
 
-    print(room_array)
+    Logger.log(room_array)
 
     with db:
         cur = db.cursor()
@@ -834,13 +834,13 @@ def get_device_data(username, type, id, db):
                            'icon': data['ICON']}
         #MQTT-Sensor
         elif type == MQTT_SENSOR:
-            cur.execute("SELECT * FROM MQTT_SENSORS WHERE ID = :id", param_array)
+            cur.execute("SELECT * FROM MQTT_SENSORS, MQTT_DEVICES WHERE MQTT_SENSORS.DEVICE_ID = MQTT_DEVICES.ID AND MQTT_SENSORS.ID = :id", param_array)
 
             data = cur.fetchone()
 
             device_data = {'room': room_array[int(data['ROOM'])], 'location': data['ROOM'], 'name': data['NAME'], 'icon': data['ICON'],
                            'topic': data['TOPIC'], 'key': data['KEY'], 'sensor_type': data['TYPE'],
-                           'sensor_type_name': SENSOR_TYPE_MAP[data['TYPE']]['name'], 'save_data': data['SAVE_DATA']}
+                           'sensor_type_name': SENSOR_TYPE_MAP[data['TYPE']]['name'], 'save_data': data['SAVE_DATA']==1}
         #IP Kamera
         elif type == IP_CAM:
             cur.execute("SELECT * FROM ZWAVE_DIMMER WHERE ID = :id", param_array)
@@ -887,6 +887,20 @@ def get_device_data(username, type, id, db):
             data = cur.fetchone()
             device_data = {'room': room_array[int(data['RAUM'])], 'location': data['RAUM'], 'name': data['NAME'],
                            'icon': data['ICON']}
+        #Wake on Lan
+        elif type == WAKE_ON_LAN:
+            cur.execute("SELECT * FROM WAKE_ON_LAN WHERE DEVICE = :id", param_array)
+
+            data = cur.fetchone()
+            device_data = {'room': room_array[int(data['LOCATION'])], 'location': data['LOCATION'], 'name': data['NAME'],
+                           'icon': data['ICON'], 'mac': data['MAC_ADDRESS']}
+        #XBOX Wake on Lan
+        elif type == XBOX_ONE_WOL:
+            cur.execute("SELECT * FROM XBOX_ONE_WOL WHERE ID = :id", param_array)
+
+            data = cur.fetchone()
+            device_data = {'room': room_array[int(data['LOCATION'])], 'location': data['LOCATION'], 'name': data['NAME'],
+                           'icon': data['ICON'], 'ip': data['IP_ADDRESS'], 'liveid': data['XBOX_LIVE_ID']}
         #Rademacher
         elif type == RADEMACHER_THERMOSTAT:
             cur.execute("SELECT * FROM HOMEPILOT_THERMOSTATS WHERE ID = :id", param_array)
@@ -895,7 +909,7 @@ def get_device_data(username, type, id, db):
             device_data = {'room': room_array[int(data['ROOM'])], 'location': data['ROOM'], 'name': data['NAME'],
                            'icon': data['ICON']}
         elif type == RADEMACHER_BLIND_CONTROL:
-            cur.execute("SELECT * FROM HOMEPILOT_THERMOSTATS WHERE ID = :id", param_array)
+            cur.execute("SELECT * FROM HOMEPILOT_BLIND_CONTROL WHERE ID = :id", param_array)
 
             data = cur.fetchone()
             device_data = {'room': room_array[int(data['LOCATION'])], 'location': data['LOCATION'], 'name': data['NAME'],
