@@ -1,5 +1,5 @@
-from homevee.Functions.room_data import get_room_name
 from homevee.Helper.helper_functions import has_permission
+from homevee.items.Room import Room
 
 
 def get_smart_speakers(username, db):
@@ -13,7 +13,8 @@ def get_smart_speakers(username, db):
         for speaker in cur.fetchall():
             if has_permission(username, speaker['LOCATION'], db):
                 item = {'name': speaker['NAME'], 'id': speaker['ID'], 'key': speaker['KEY'],
-                        'location': speaker['LOCATION'], 'location_name': get_room_name(speaker['LOCATION'], db)}
+                        'location': speaker['LOCATION'], 'location_name': Room.get_name_by_id(speaker['LOCATION'],
+                                                                                              db)}
 
                 speakers.append(item)
 
